/**********************************************************************************/
/*    Demo program for:          								                        				  */
/*	  Board: BB-VNH3SP30                 									                    	  */
/*    Manufacture: OLIMEX                                                     	  */
/*	  COPYRIGHT (C) 2017                            														  */
/*    Designed by: Engineer Stefan Mavrodiev                                      */
/*    Module Name    :  main module                                               */
/*    File   Name    :  main.c                                                    */
/*    Revision       :  1.3.0			                                                */
/*    Date           :  17.08.2017                                                */
/*    Built with Arduino C/C++ Compiler, version: 1.0.5                           */
/**********************************************************************************/

// Description: This simple program is designed by using Olimexino-328 board and 
// BB-VNH3SP30 connected to it. Alternatively, the power for the motor could be 
// provided by the board's power IF AND ONLY IF the rating of the motor is compatible
// with Olimexino's output performance, in particular current requirements. In this 
// case, you connect one of the power outputs (5 V or 3.3 V) of the Olimexino to 
// CTRL <1> which is connected to VIN (in contrast to the layout below). 
// (You must disconnect other power sources.)
//
// DO NOT PROVIDE POWER SIMULTANEOUSLY BY OLIMEXINO (TO CTRL1) AND BY AN EXTERNAL SOURCE
// TO VIN! AS CTRL 1 IS DIRECTLY CONNECTED TO VIN, THIS COULD DAMAGE ALL COMPONENTS.
// 
// BE VERY CAREFUL WITH THE HARDWARE CONNECTIONS. INCORRECT POWER SUPPLY MIGHT LEAD 
// TO HARDWARE DAMAGE!
//
//      |---------------------------------------------------------------------|
//      |            The hardware connections are as follows:                 |
//      |--------------------------------|------------------------------------|
//      |  Connector at OLIMEXINO-328    |  CTRL connector at BB-VNH3SP30 |
//      |--------------------------------|------------------------------------|
//      |    Not connected to OLIMEXINO! |    CTRL<1>,  VIN                   |
//      |    Power<3>, 5V         	     |    CTRL<2>,  +5V                   |
//      |    Power<4>, GND               |    CTRL<3>,  GND                   |
//      |    Digital<9>                  |    CTRL<4>,  INA                   |
//      |    Digital<13>                 |    CTRL<5>,  INB                   |
//      |    Digital<11>                 |    CTRL<6>,  PWM                   |
//      |    Digital<10>                 |    CTRL<7>,  ENA/DIAGA             |
//      |    Digital<12>                 |    CTRL<8>,  ENB/DIAGB             |
//      |--------------------------------|------------------------------------|
//      |  External power supply         |  PWR connector at BB-VNH3SP30      |
//      |--------------------------------|------------------------------------|     
//      |    GND (-)                     |    GND (-)                         |
//      |    VCC (+) (5.5V-36V!!!)       |    VIN (+)                         |
//      |--------------------------------|------------------------------------|
//
// Connect pot or trimmer on analog pin 0 (A0). According to the value PWM changes 
// and speed of the rotation of the motor. The motor start to rotate CW. Then when 
// the BUT is pressed the rotation start. After one more press of BUT the motor 
// start to rotate CCW direction.
// 
// Demo revision history
// 
// Revision: 1.3.0 - Improved description
//
// Revision: 1.2.0 - Fixed the table for the layout of the connections. Added notes 
// about VIN and PWR.
//
// Revision: 1.1.0 - Fixed the table for the layout of the connections. Added note 
// about possible hardware damage.
//
// Revision: 1.0.0 - (initial)
//

const int inaPin = 13;
const int inbPin = 9;
const int pwmPin = 11;
const int diagaPin = 10;
const int diagbPin = 12;
const int buttonPin = 2;
const int trimPin = A0;

int i = 0;

void setup() {
  pinMode(buttonPin, INPUT);
  pinMode(inaPin, OUTPUT);
  pinMode(inbPin, OUTPUT);
  pinMode(pwmPin, OUTPUT);
  pinMode(diagaPin, INPUT);
  pinMode(diagbPin, INPUT);
  pinMode(trimPin, INPUT);
 
}

void loop() {
  
  // CW
  digitalWrite(inaPin, HIGH);
  digitalWrite(inbPin, LOW);
  while(digitalRead(buttonPin) == HIGH){
    i = analogRead(trimPin);
    analogWrite(pwmPin, map(i, 0, 1023, 0, 255));

  }
  while(digitalRead(buttonPin) == LOW);
  delay(500);
  
  //STOP
  digitalWrite(inaPin, LOW);
  digitalWrite(inbPin, LOW);
  while(digitalRead(buttonPin) == HIGH);
  while(digitalRead(buttonPin) == LOW);
  delay(500);
  
  // CCW
  digitalWrite(inaPin, LOW);
  digitalWrite(inbPin, HIGH);
  while(digitalRead(buttonPin) == HIGH){
    i = analogRead(trimPin);
    analogWrite(pwmPin, map(i, 0, 1023, 0, 255)); 
  }
  while(digitalRead(buttonPin) == LOW);
  delay(500);
  
   //STOP
  digitalWrite(inaPin, HIGH);
  digitalWrite(inbPin, HIGH);
  while(digitalRead(buttonPin) == HIGH);
  while(digitalRead(buttonPin) == LOW);
  delay(500);
  
}
